@@ -1,23 +1,23 @@
-/***************************************************************************
-    begin                : Thu Sep 12 2002
-    copyright            : (C) 2002 - 2004 by Scott Wheeler,
-    email                : wheeler@kde.org
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/**
+ * Copyright (C) 2002-2004 Scott Wheeler <wheeler@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the License, or (at your option) any later
+ * version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "playlistbox.h"
 
 #include <kicon.h>
 #include <kiconloader.h>
-#include <k3urldrag.h>
 #include <kmessagebox.h>
 #include <kmenu.h>
 #include <kaction.h>
@@ -503,7 +503,7 @@ void PlaylistBox::contentsDragMoveEvent(QDragMoveEvent *e)
     //
     // Otherwise, do not accept the event.
 
-    if(!K3URLDrag::canDecode(e)) {
+    if (!KUrl::List::canDecode(e->mimeData())) {
         e->setAccepted(false);
         return;
     }
